[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php PHPInstallerBase52.wxs PHPInstallerBase52NTS.wxs PHPInstallerBase53.wxs PHPInstallerBase53NTS.wxs PHPInstallerBase60.wxs PHPInstallerBase60NTS.wx

2009-06-25 Thread John Mertic
jmertic Thu Jun 25 15:59:13 2009 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php PHPInstallerBase52.wxs 
PHPInstallerBase52NTS.wxs PHPInstallerBase53.wxs 
PHPInstallerBase53NTS.wxs PHPInstallerBase60.wxs 
PHPInstallerBase60NTS.wxs 
  Log:
  Added including the readme-redist-bins.txt with the installer only if it 
exists.
  http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.13r2=1.14diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.13 
win-installer/GenPHPInstaller.wxs.php:1.14
--- win-installer/GenPHPInstaller.wxs.php:1.13  Wed Apr  1 19:47:32 2009
+++ win-installer/GenPHPInstaller.wxs.php   Thu Jun 25 15:59:13 2009
@@ -41,8 +41,6 @@
$MergeRef-setAttribute('Id','VCRedist_policy');
 }
 
-$PHPInstallerBaseWXS-save(PHPInstaller$version.wxs);
-
 // remove extension info from php.ini-production
 if ( is_file(Files/php.ini-production) )
$infile = fopen(Files/php.ini-production,'r');
@@ -62,5 +60,31 @@
 fclose($infile);
 fclose($outfile);
 
+// check for presence of certain file; if not there then remove the feature 
from the installer
+$files = array(
+'readme-redist-bins.txt' = 'readmedistbinsTXT',
+);
+
+foreach ( $files as $filename = $component ) {
+if ( !file_exists(Files/$filename) ) {
+$Components = $PHPInstallerBaseWXS-getElementsByTagName('Component');
+foreach ( $Components as $Component ) {
+if ( $Component-getAttribute('Id') == $component ) {
+$Component-parentNode-removeChild($Component);
+break;
+}
+}
+$ComponentRefs = 
$PHPInstallerBaseWXS-getElementsByTagName('ComponentRef');
+foreach ( $ComponentRefs as $ComponentRef ) {
+if ( $ComponentRef-getAttribute('Id') == $component ) {
+$ComponentRef-parentNode-removeChild($ComponentRef);
+break;
+}
+}
+}
+}
+
+$PHPInstallerBaseWXS-save(PHPInstaller$version.wxs);
+
 exit;
 ?
http://cvs.php.net/viewvc.cgi/win-installer/PHPInstallerBase52.wxs?r1=1.44r2=1.45diff_format=u
Index: win-installer/PHPInstallerBase52.wxs
diff -u win-installer/PHPInstallerBase52.wxs:1.44 
win-installer/PHPInstallerBase52.wxs:1.45
--- win-installer/PHPInstallerBase52.wxs:1.44   Mon Jun  8 21:02:56 2009
+++ win-installer/PHPInstallerBase52.wxsThu Jun 25 15:59:13 2009
@@ -164,6 +164,14 @@
   Name=news.txt 
   Source=Files\news.txt/
   /Component
+  Component Id=readmedistbinsTXT 
+DiskId=1 
+Guid=23359910-5f6e-11de-8a39-0800200c9a66
+File Id=filereadmedistbinsTXT 
+Name=README_1.TXT 
+LongName=readme-redist-bins.txt
+Source=Files\readme-redist-bins.txt/
+  /Component
   Component Id=phpcgiEXE 
 DiskId=1 
 Guid=7ECF5817-CAB7-41EE-9E91-DDD2B1F5951B
@@ -353,6 +361,7 @@
   Level=1
   ComponentRef Id=licenseTXT/
   ComponentRef Id=newsTXT/
+  ComponentRef Id=readmedistbinsTXT/
   ComponentRef Id=installTXT/
   ComponentRef Id=phpGIF/
   ComponentRef Id=phprecommendedINI/
http://cvs.php.net/viewvc.cgi/win-installer/PHPInstallerBase52NTS.wxs?r1=1.20r2=1.21diff_format=u
Index: win-installer/PHPInstallerBase52NTS.wxs
diff -u win-installer/PHPInstallerBase52NTS.wxs:1.20 
win-installer/PHPInstallerBase52NTS.wxs:1.21
--- win-installer/PHPInstallerBase52NTS.wxs:1.20Mon Jun  8 21:02:56 2009
+++ win-installer/PHPInstallerBase52NTS.wxs Thu Jun 25 15:59:13 2009
@@ -142,6 +142,14 @@
   Name=news.txt 
   Source=Files\news.txt/
   /Component
+  Component Id=readmedistbinsTXT 
+DiskId=1 
+Guid=23359910-5f6e-11de-8a39-0800200c9a66
+File Id=filereadmedistbinsTXT 
+Name=README_1.TXT 
+LongName=readme-redist-bins.txt
+Source=Files\readme-redist-bins.txt/
+  /Component
   Component Id=phpcgiEXE 
 DiskId=1 
 Guid=7ECF5817-CAB7-41EE-9E91-DDD2B1F5951B
@@ -331,6 +339,7 @@
   Level=1
   ComponentRef Id=licenseTXT/
   ComponentRef Id=newsTXT/
+  ComponentRef Id=readmedistbinsTXT/
   ComponentRef Id=installTXT/
   ComponentRef Id=phpGIF/
   ComponentRef Id=phprecommendedINI/
http://cvs.php.net/viewvc.cgi/win-installer/PHPInstallerBase53.wxs?r1=1.23r2=1.24diff_format=u
Index: win-installer/PHPInstallerBase53.wxs
diff -u win-installer/PHPInstallerBase53.wxs:1.23 
win-installer/PHPInstallerBase53.wxs:1.24
--- win-installer/PHPInstallerBase53.wxs:1.23   Mon Jun  8 21:02:56 2009
+++ win-installer/PHPInstallerBase53.wxsThu Jun 25 15:59:13 2009
@@ -157,12 +157,13 @@
   Name=news.txt 
   Source=Files\news.txt/
   /Component
-   

[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php

2009-04-01 Thread John Mertic
jmertic Wed Apr  1 19:47:32 2009 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php 
  Log:
  Fix check for correct php.ini to work for 5.2 and 5.3+ install builds.
  
http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.12r2=1.13diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.12 
win-installer/GenPHPInstaller.wxs.php:1.13
--- win-installer/GenPHPInstaller.wxs.php:1.12  Tue Mar 24 22:13:00 2009
+++ win-installer/GenPHPInstaller.wxs.php   Wed Apr  1 19:47:32 2009
@@ -44,7 +44,10 @@
 $PHPInstallerBaseWXS-save(PHPInstaller$version.wxs);
 
 // remove extension info from php.ini-production
-$infile = fopen(Files/php.ini-production,'r');
+if ( is_file(Files/php.ini-production) )
+   $infile = fopen(Files/php.ini-production,'r');
+else
+   $infile = fopen(Files/php.ini-recommended,'r');
 $outfile = fopen(Files/php.ini,'w');
 if (!$outfile || !$infile) {
echo Cannot open php.ini or php.ini-production\n;



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php policy_9_0_Microsoft_VC90_CRT_x86.msm policy_9_0_Microsoft_VC90_CRT_x86_x64.msm

2008-12-20 Thread John Mertic
jmertic Sun Dec 21 03:43:07 2008 UTC

  Added files: 
/win-installer  policy_9_0_Microsoft_VC90_CRT_x86.msm 
policy_9_0_Microsoft_VC90_CRT_x86_x64.msm 

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php 
  Log:
  Add the policy msm files to the installer. Should make the VC9 runtime be 
automatically installed if not present if needed.
  http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.10r2=1.11diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.10 
win-installer/GenPHPInstaller.wxs.php:1.11
--- win-installer/GenPHPInstaller.wxs.php:1.10  Wed Dec  3 21:18:29 2008
+++ win-installer/GenPHPInstaller.wxs.php   Sun Dec 21 03:43:07 2008
@@ -25,20 +25,20 @@

$Merge-setAttribute('SourceFile',Microsoft_VC90_CRT_{$includemsm}.msm);
$Merge-setAttribute('DiskId','1');
$Merge-setAttribute('Language','0');
-   
+   $Merge = $PHPInstallerBaseWXS-createElement('Merge');
+   $Merge = $TargetDir-appendChild($Merge);
+   $Merge-setAttribute('Id','VCRedist_policy');
+   
$Merge-setAttribute('SourceFile',policy_9_0_Microsoft_VC90_CRT_{$includemsm}.msm);
+   $Merge-setAttribute('DiskId','1');
+   $Merge-setAttribute('Language','0');
+
$MainFeature = 
$PHPInstallerBaseWXS-getElementsByTagName('Feature')-item(0);
-   $Feature = $PHPInstallerBaseWXS-createElement('Feature');
-   $Feature = $MainFeature-appendChild($Feature);
-   $Feature-setAttribute('Id','VCRedistFeature');
-   $Feature-setAttribute('Title','Visual C++ 9.0 Runtime');
-   $Feature-setAttribute('AllowAdvertise','no');
-   $Feature-setAttribute('Display','hidden');
-   $Feature-setAttribute('Level','1');
-$Feature-setAttribute('InstallDefault','source');
-   
$MergeRef = $PHPInstallerBaseWXS-createElement('MergeRef');
-   $MergeRef = $Feature-appendChild($MergeRef);
+   $MergeRef = $MainFeature-appendChild($MergeRef);
$MergeRef-setAttribute('Id','VCRedist');
+$MergeRef = $PHPInstallerBaseWXS-createElement('MergeRef');
+   $MergeRef = $MainFeature-appendChild($MergeRef);
+   $MergeRef-setAttribute('Id','VCRedist_policy');
 }
 
 $PHPInstallerBaseWXS-save(PHPInstaller$version.wxs);

http://cvs.php.net/viewvc.cgi/win-installer/policy_9_0_Microsoft_VC90_CRT_x86.msm?view=markuprev=1.1
Index: win-installer/policy_9_0_Microsoft_VC90_CRT_x86.msm
+++ win-installer/policy_9_0_Microsoft_VC90_CRT_x86.msm
ÐÏࡱá



¥³¯ZÓ1Øfr
Ýy'¥e²Sqfþܝ 
}iÊü9Ø¤W¡²ÄùgGô#–J’¥½™üŒ¸|óZÑ´ÀºµØùeÝ53eMÅSŽu'›º7ÕÔeì÷¾IàhÙ¨GĈ„]­Ôk3³’I'þ(^Ît...@ö_¿ñ:çP¯¼?bê׬}¡¨¦¦É ÁêПÀùW¼y¢Iþx¹i“ùá¦fúöõ
«”0ÕüÖvMÑãúª½›Ñ)òåG=†×ÙÄT5ZtD0ϽÝ{ãÐÝó]—HþžÁë=ÇÊ+ÞÆ^¿?qá3ÿÎmR
*m{k¯ùyø™;ôLÖeGߍŠ°„k¦¾¯Ïbs”ð6½ß[課¿\Qæ¸ÝGŒ°¦;хÝ‚¢±îhtí‰ÓTÚÛÌýJ˸xڗ:üF?9-k÷®ÖÂx7LVg´•¢”«·ñ¡A•^›«ó×D}'dO
   ÌÝã}Ë=C
иs4¯ÕåsIœjÅ\êöÃçØTrÉ:%³VJnØg,B.i÷AÃä¡‘ùy†þ¯XâýöÚ5Œ±è¬ çOá(òíA8b•`ìðŒ·ö?®ýiáé'€J݇n

³©æKÊug…qö7N|àPkÀά¼Tik+6Ž=Z‘ïÈ9x¸\gmÇÇ¢‚æŠ+¶’k)l¤ðÝLyRã¾e~aR•c¦yn°ÔhxþÒ‡qvJg냁¤ú‘º÷ÃÞ4_ÂtÅ_¿G¸¥Ñ!,Y8¨“Qº6
 K2¡§¬ŒßáðLf#ÑC^.Óí Î]b°Yu[q´¶uÞy|ù+z`ª5/ 
yØ#’À‚81•Ç©ì3I¨Z‚÷çÍû˜hÇJ™É«ZO?‘w3›Êä“Ô‚‹Å±Ü©|¶ñŽ½^máÁ1OÍÄ©™­%A¶ÚÝT£«Ò³h:â
©8
FÅÿÂe£³¾¿þωj…¿;šsÅGÐe¿VÀ‰æ^ñ±¶”þ~S/up®ñpw÷ÈÎúëós]q�...@ÿ§¬bãa·“h#ÀæŸú‚
kßÀb¦fGŸÄ§h4— 
¶‡D2+;%ÓՎÊãR^Öe•å{9_ÔÛ}Û£öã3¶G¶Ytãj0pàQ\Zڍ»ëIëë|Ÿml0š1zà¥ø4p...@z„›bˆs5lÛ}ӈׇ›¶‘lò®×
Õ+nš9†^»Æ¼â*1vÃi.{ƒÉöó7ØmºŒ*‰úՅ,N¬óä3H`þô`ò WmkÃB¼–82y8!¶ßãã…
7ÂOçjξÝÚü¹Å™˜,]åÍrs¼_²1‹bD0¬úž·džéì[$¿¨·½Ö8Óóùvr¸}-ðR³q‡Í(—_Òák¿š_©ØþãqùÇi臧
Ö/q™³ãOAùõ'FP~³0£y¾~ „F«¡1ª.
ʔ†z%~̈È~E™gøñNeç˜?€ŠCÎ1¼¹Å%f÷u‡ï-КQ9ø°])×U÷™yú®Ä]YÓ;––R¨êrÙ¶ÝÔ7ìê‰1ahRÿNڋ͇ÔÎԄüÆZñ(—ôlîxËȳ‚Lb¾Ãkߗýw}}N ¶³„E/tjoÍ�...@¾‰(]’µtq:m¦‘ÞAªÞ6z|`’x¡¹Iyì³ÚõÅeVzºÁ¦V5zñqb3Iè.ʾLËÚÅöLYÂ*£]ë$ԔôUj”^‘N*aÓòuÙû‰bùT
 éyÑUƒ±ŒÜ¶Mï;lí¯ohn–z£žTÓdjîàh;q9N4{ºMð¦‰1Lþý5]ƒ`?_d ‘
Iv÷ƒt¿K(,
D}såˆÃ‚(œƒÔ÷î`À Aõô @ P¨†T‚7‰F$ÐöR¡º‚µ4 
Û^T£1ā²›Èpʓ …WÅcÝÑD´Q/¥²ì¢џH†Ü#„0Äï2Íð‹ïËêÿ¾)_Ûð3Çÿy¡‹ãIdÆèCÉN¢B5 
‘_ÇzÊ:-¨üCAŽ?ë6}]•Ÿ6ó»z¹7tUÜ¿ÿ:6öÂmC.Ç79êgÓmÈÌWÔöÉÔÚyê¥[µ*†«’þÿ

®Onò±{W×Ď  •¹ñ~M9~Ç8ߐö„äöC—#n?ävêEqPƒ

ñß[‡£@;  K`ä¶1ä–:ä”!Ô
-Šý^xõ
՝F¢Ñ’à:†...@ø»ÝŽb¡!÷Ò¼)t-”âÂj�...@
5H‹2~Í­™ÃЉzÙ¼þՋüÖ¤úOí¸Q¤õ+ü¾ËDš5e•osùÊòò?8ˆÍK6w¯ž¶+ã0¬ŸéBsϼ|¹lgk'íîÖ¾¸~B¢Ùď+ˆn釟Œf*Ûse Éi‚¸ù®Cy“ÿґîwlÉá•i·/j*ýúÛù ÑÀ ÝÇ ¡Sãà°!ÿyuŸµýê#Ä¿7F4¹¨j‘·ˆqá+8ò?ìr00¹/¶õœ?¿vü±½Ù9Sáo*üM…¿©ð'*¸tËß©ÀºÈ÷ÄfÉõô½ú¯w3â¿
PÞka D
Ùã«cÿÈ1iPòwÇDWÚ=ˆH{’ªiƒ3üK*T„ìïÞQjŒ=¯V„î›—UßTÿq]Ö]ã=o;Lƾ¹ÛÒ?“¿¹¥g³¯ŠŒ±ît§YEÄÞãÚÉÜ6·e§r^pI¯ë0”YÀ§·‰Ÿ=f¾.ý~©ŠÔMså0Jïj
Ãx...@­ÂŒ§Ž2³´¸ÞìÜ5_X|æǪ«„ú¼kNTLlRÉTej~›Ö9›X¡õñVà, 7sg^/êFܸ/¶
À`Kf  ځâ7bB°UüA à¿ýòdß-«[#T¾áÈÉ0ó 
PÅ­HeÆì»x)Ü\nêA-Ïy=mÃÞÒ¸Ï-Sƒ-/[^?!ÝæΛ†ãî´Ä·ÎÙ·6f×:RÞŒ
€‰M]b•œÙ\©û$Šö¿?P”ˆMÒ;éS£åיpYúóÐËnûфÚÅ 

[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php

2008-12-03 Thread John Mertic
jmertic Wed Dec  3 21:18:30 2008 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php 
  Log:
  Don't use the same id for the msm merge element and feature element.
  
http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.9r2=1.10diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.9 
win-installer/GenPHPInstaller.wxs.php:1.10
--- win-installer/GenPHPInstaller.wxs.php:1.9   Mon Oct 20 15:01:28 2008
+++ win-installer/GenPHPInstaller.wxs.php   Wed Dec  3 21:18:29 2008
@@ -29,11 +29,12 @@
$MainFeature = 
$PHPInstallerBaseWXS-getElementsByTagName('Feature')-item(0);
$Feature = $PHPInstallerBaseWXS-createElement('Feature');
$Feature = $MainFeature-appendChild($Feature);
-   $Feature-setAttribute('Id','VCRedist');
+   $Feature-setAttribute('Id','VCRedistFeature');
$Feature-setAttribute('Title','Visual C++ 9.0 Runtime');
$Feature-setAttribute('AllowAdvertise','no');
$Feature-setAttribute('Display','hidden');
$Feature-setAttribute('Level','1');
+$Feature-setAttribute('InstallDefault','source');

$MergeRef = $PHPInstallerBaseWXS-createElement('MergeRef');
$MergeRef = $Feature-appendChild($MergeRef);



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php PHPInstallerBase52.wxs PHPInstallerBase53.wxs WebServerConfig53.wxs

2008-10-13 Thread Pierre-Alain Joye
pajoye  Mon Oct 13 09:57:01 2008 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php PHPInstallerBase52.wxs 
PHPInstallerBase53.wxs WebServerConfig53.wxs 
  Log:
  - disabe apache1 in the installer
  
http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.7r2=1.8diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.7 
win-installer/GenPHPInstaller.wxs.php:1.8
--- win-installer/GenPHPInstaller.wxs.php:1.7   Thu Sep 11 19:16:37 2008
+++ win-installer/GenPHPInstaller.wxs.php   Mon Oct 13 09:57:01 2008
@@ -45,6 +45,10 @@
 // remove extension info from php.ini-recommended
 $infile = fopen(Files/php.ini-recommended,'r');
 $outfile = fopen(Files/php.ini,'w');
+if (!$outfile || $infile) {
+   echo Cannot open php.ini or php.ini-recommended\n;
+   exit(1);
+}
 while (!feof($infile)) {
 $buffer = fgets($infile);
 if ( stristr($buffer,';extension') === FALSE ) {
http://cvs.php.net/viewvc.cgi/win-installer/PHPInstallerBase52.wxs?r1=1.26r2=1.27diff_format=u
Index: win-installer/PHPInstallerBase52.wxs
diff -u win-installer/PHPInstallerBase52.wxs:1.26 
win-installer/PHPInstallerBase52.wxs:1.27
--- win-installer/PHPInstallerBase52.wxs:1.26   Fri Sep 12 16:03:32 2008
+++ win-installer/PHPInstallerBase52.wxsMon Oct 13 09:57:01 2008
@@ -399,8 +399,10 @@
   Title=$(loc.Featureapache13Title) 
   Description=$(loc.Featureapache13Description) 
   Level=10
+!--
   ComponentRef Id=php5apacheDLL/
   ComponentRef Id=php5apache_hooksDLL/
+--
   ComponentRef Id=phpwinEXE/
   ComponentRef Id=apache13registry/
 /Feature
@@ -420,7 +422,7 @@
   Title=$(loc.Featureapache22Title) 
   Description=$(loc.Featureapache22Description) 
   Level=10
-  ComponentRef Id=php5apache2_2DLL/
+ ComponentRef Id=php5apache2_2DLL/
   ComponentRef Id=php5apache2_2_filterDLL/
   ComponentRef Id=php5apache_hooksDLL/
   ComponentRef Id=phpwinEXE/
http://cvs.php.net/viewvc.cgi/win-installer/PHPInstallerBase53.wxs?r1=1.3r2=1.4diff_format=u
Index: win-installer/PHPInstallerBase53.wxs
diff -u win-installer/PHPInstallerBase53.wxs:1.3 
win-installer/PHPInstallerBase53.wxs:1.4
--- win-installer/PHPInstallerBase53.wxs:1.3Fri Sep 12 16:03:32 2008
+++ win-installer/PHPInstallerBase53.wxsMon Oct 13 09:57:01 2008
@@ -378,8 +378,10 @@
   Title=$(loc.Featureapache13Title) 
   Description=$(loc.Featureapache13Description) 
   Level=10
+!--
   ComponentRef Id=php5apacheDLL/
   ComponentRef Id=php5apache_hooksDLL/
+--
   ComponentRef Id=phpwinEXE/
   ComponentRef Id=apache13registry/
 /Feature
@@ -390,7 +392,7 @@
   Level=10
   ComponentRef Id=php5apache2DLL/
   ComponentRef Id=php5apache2_filterDLL/
-  ComponentRef Id=php5apache_hooksDLL/
+!-- ComponentRef Id=php5apache_hooksDLL/ --
   ComponentRef Id=phpwinEXE/
   ComponentRef Id=apache20registry/
 /Feature
@@ -401,7 +403,7 @@
   Level=10
   ComponentRef Id=php5apache2_2DLL/
   ComponentRef Id=php5apache2_2_filterDLL/
-  ComponentRef Id=php5apache_hooksDLL/
+!--  ComponentRef Id=php5apache_hooksDLL/--
   ComponentRef Id=phpwinEXE/
   ComponentRef Id=apache22registry/
 /Feature
http://cvs.php.net/viewvc.cgi/win-installer/WebServerConfig53.wxs?r1=1.1r2=1.2diff_format=u
Index: win-installer/WebServerConfig53.wxs
diff -u win-installer/WebServerConfig53.wxs:1.1 
win-installer/WebServerConfig53.wxs:1.2
--- win-installer/WebServerConfig53.wxs:1.1 Fri Aug 22 18:51:40 2008
+++ win-installer/WebServerConfig53.wxs Mon Oct 13 09:57:01 2008
@@ -2,9 +2,11 @@
 Wix xmlns='http://schemas.microsoft.com/wix/2003/01/wi'
   Fragment Id='FragmentWebServerConfig'
 DirectoryRef Id='INSTALLDIR'
+!--
   Component Id=php5apacheDLL DiskId=1 
Guid=FEEF42A9-BCCA-44DD-88E5-501D39B87DA0
 File Id=filephp5apacheDLL Name=PHP5AP_1.DLL 
LongName=php5apache.dll Source=Files\php5apache.dll /
   /Component
+--
   Component Id=php5apache2DLL DiskId=1 
Guid=97997967-0ED5-4695-A714-F1333A0FC1B9
 File Id=filephp5apache2DLL Name=PHP5AP_2.DLL 
LongName=php5apache2.dll Source=Files\php5apache2.dll /
   /Component
@@ -17,9 +19,11 @@
   Component Id=php5apache2_2_filterDLL DiskId=1 
Guid=828FA07E-3624-11DC-8CB8-308555D89593
 File Id=filephp5apache2_2_filterDLL Name=PHP5AP_3.DLL 
LongName=php5apache2_2_filter.dll Source=Files\php5apache2_2_filter.dll /
   /Component
+!--
   Component Id=php5apache_hooksDLL DiskId=1 
Guid=C4DB476D-1A0A-4C46-826C-1D3FD4BA45D0
 File Id=filephp5apache_hooksDLL Name=PHP5AP_4.DLL 
LongName=php5apache_hooks.dll Source=Files\php5apache_hooks.dll /
   /Component
+--
   Component Id=php5isapiDLL 

[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php build.bat

2008-09-11 Thread John Mertic
jmertic Thu Sep 11 19:16:37 2008 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php build.bat 
  Log:
  Enable installer for VC9 x64 PHP builds.
  
http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.6r2=1.7diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.6 
win-installer/GenPHPInstaller.wxs.php:1.7
--- win-installer/GenPHPInstaller.wxs.php:1.6   Thu Sep 11 18:54:56 2008
+++ win-installer/GenPHPInstaller.wxs.php   Thu Sep 11 19:16:37 2008
@@ -22,7 +22,7 @@
$Merge = $PHPInstallerBaseWXS-createElement('Merge');
$Merge = $TargetDir-appendChild($Merge);
$Merge-setAttribute('Id','VCRedist');
-   $Merge-setAttribute('SourceFile','Microsoft_VC90_CRT_x86.msm');
+   
$Merge-setAttribute('SourceFile',Microsoft_VC90_CRT_{$includemsm}.msm);
$Merge-setAttribute('DiskId','1');
$Merge-setAttribute('Language','0');

http://cvs.php.net/viewvc.cgi/win-installer/build.bat?r1=1.12r2=1.13diff_format=u
Index: win-installer/build.bat
diff -u win-installer/build.bat:1.12 win-installer/build.bat:1.13
--- win-installer/build.bat:1.12Thu Sep 11 18:54:56 2008
+++ win-installer/build.bat Thu Sep 11 19:16:37 2008
@@ -17,12 +17,16 @@
 if %2==nts set suffix=NTS
 if %2==vc9 set extrabuildtype=vc9-
 if %2==vc9 set includevc9msm=x86
+if %2==x64 set extrabuildtype=vc9-x64-
+if %2==x64 set includevc9msm=x86_x64
 
 if (%3)==() goto build
 if %3==nts set extrants=nts-
 if %3==nts set suffix=NTS
 if %3==vc9 set extrabuildtype=vc9-
 if %3==vc9 set includevc9msm=x86
+if %3==x64 set extrabuildtype=vc9-x64-
+if %3==x64 set includevc9msm=x86_x64
 
 :build
 set msiname=php-%1-%extrants%win32-%extrabuildtype%installer.msi



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: win-installer / GenPHPInstaller.wxs.php

2009-03-24 Thread Pierre-Alain Joye
pajoye  Tue Mar 24 22:13:00 2009 UTC

  Modified files:  
/win-installer  GenPHPInstaller.wxs.php 
  Log:
  - new php.ini names
  
http://cvs.php.net/viewvc.cgi/win-installer/GenPHPInstaller.wxs.php?r1=1.11r2=1.12diff_format=u
Index: win-installer/GenPHPInstaller.wxs.php
diff -u win-installer/GenPHPInstaller.wxs.php:1.11 
win-installer/GenPHPInstaller.wxs.php:1.12
--- win-installer/GenPHPInstaller.wxs.php:1.11  Sun Dec 21 03:43:07 2008
+++ win-installer/GenPHPInstaller.wxs.php   Tue Mar 24 22:13:00 2009
@@ -43,11 +43,11 @@
 
 $PHPInstallerBaseWXS-save(PHPInstaller$version.wxs);
 
-// remove extension info from php.ini-recommended
-$infile = fopen(Files/php.ini-recommended,'r');
+// remove extension info from php.ini-production
+$infile = fopen(Files/php.ini-production,'r');
 $outfile = fopen(Files/php.ini,'w');
 if (!$outfile || !$infile) {
-   echo Cannot open php.ini or php.ini-recommended\n;
+   echo Cannot open php.ini or php.ini-production\n;
exit(1);
 }
 while (!feof($infile)) {



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php